@@ -10,9 +10,22 @@
 #' @param scale_area Optional. A number by which the areas of the points are scaled. Use if points are to small or to big.
 #' @param indicate_bins Logical, specifying whether to connect points to their respective bin (center of hexagon).
 #' @param category_labels A vector of length 3 containing the category names, e.g. \code{c("1","2","3")} (default)
+#' @param use_pvals Logical, determines whether multinomial p-values are used for uncertainty quantification, see details.
+#' @param alphas Vector of length 2 with values 1 > \code{alphas[1]} > \code{alphas[2]} >= 0.0001. Only relevant if \code{use_pvals = TRUE}. 
 #' @param ... Arguments concerning the title (e.g. \code{main}, \code{cex.main}, \code{col.main} and \code{font.main})
 #'            and subtitle (e.g. \code{sub}, \code{cex.sub}, \code{col.sub} and \code{font.sub}) may be passed here.
-#'
+#' @details If multinomial p-values are used (\code{use_pvals = TRUE}), the dots are colored in the following way:
+#' \itemize{
+#'   \item Blue: p-value greater \code{alphas[1]} (0.1 by default).
+#'   \item Orange: p-value between \code{alphas[1]} and \code{alphas[2]} (0.1 and 0.01 by default)
+#'   \item Red: p-value less than \code{alphas[2]} (0.01 by default)
+#'   \item Black: p-value is exactly 0. This only happens if a category which is assigned 0 probability realizes.
+#' }
+#' Many small p-values (orange and red dots) indicate miscalibrated predictions, whereas many blue dots indicate that the predictions 
+#' may in fact be calibrated. WARNING: The use of the multinomial p-values is more of an experimental feature and may not yield reliable 
+#' p-values, especially if \code{n} is small.
+#' For details regarding the calculation of the p-values see also \code{\link{calibration_simplex}}.
+#' 
 #' @note For details on the meaning of the error scale, cf. Wilks, 2013, especially Fig. 2. Note that the miscalibration error in
 #' each category is in "probability units" (as it is the average difference in relative frequency and forecast probability
 #' in each bin).
@@ -25,6 +38,8 @@
 #' @importFrom spatstat owin coords hexgrid hextess square
 
 plot.calibration_simplex = function(x,
+                                    #alpha = 0.05,
+                                    
                                     true_error = TRUE,
                                     error_scale = 0.3,
                                     min_bin_freq = 10,
@@ -32,6 +47,8 @@ plot.calibration_simplex = function(x,
                                     scale_area = NULL,
                                     indicate_bins = TRUE,
                                     category_labels = c("1","2","3"),
+                                    use_pvals = FALSE,
+                                    alphas = c(0.1,0.01),
                                     ...) {
   par_old <- par(no.readonly = TRUE)
   on.exit(par(par_old))
@@ -45,9 +62,23 @@ plot.calibration_simplex = function(x,
 
   if(is.null(scale_area)) scale_area = (n/10)^2
 
-  triangle= function(centers = F) {#Höhe der Hexagone ist 1
-    a = n - 1 #a: Grundseite Dreieck, s: Seite Hexagon
-    s = 1/sqrt(3)  #~1/Wurzel(3) berechnet, sodass H?he = 1...
+  # Testing
+
+  # tests = x$pvals > alpha
+  # test_col = ifelse(tests,"blue","red")
+  # test_col[x$pvals == -1] = "violet"
+
+  #tests = x$pvals > alpha
+  test_col = ifelse(x$pvals >= alphas[1],"blue",ifelse(x$pvals >= alphas[2],"orange","red"))
+  test_col[x$pvals == -1] = "black"
+  test_col[is.na(test_col)] = "black"
+
+  # Plotting
+
+  triangle= function(centers = F) {
+    a = n - 1
+    if(a == 0) a= 0.01 # allows to plot one bin (n = 1)
+    s = 1/sqrt(3)
     sin60 = sqrt(3)/2
     x = c(0,sin60*a,0)
     y = c(0,a/2,a)
@@ -63,25 +94,37 @@ plot.calibration_simplex = function(x,
   plot(c(-2,n),c(-1,n),col="white",asp=1,bty="n",axes = F,xlab='',ylab='')
   if(is.element("main",names(list(...)))) title(...,line =-1)
   else title(main = "Calibration Simplex", line = -1,...)
-  plot(H,border="darkgrey",add = T) #col changed to border in spatstat package...
+  plot(H,border="darkgrey",add = T)
 
   centers = coords(H_centers)
   ordered_centers = centers[order(centers$x,centers$y),]
 
-  displacement = cbind(-error$c3-error$c1,
-                       0.577*error$c3-0.577*error$c1)#wie in Paper, aber x und y vertauscht!
+  displacement = cbind(-error[,3]-error[,1],0.577*error[,3]-0.577*error[,1])
+  # displacement = cbind(-error$c3-error$c1,
+  #                      0.577*error$c3-0.577*error$c1)
 
   shifted_centers = ordered_centers + 1/sqrt(3)/error_scale*displacement
 
-  symbols(shifted_centers[x$freq>=min_bin_freq,],
-          circles=sqrt(scale_area*rel_freq[x$freq>=min_bin_freq]/pi),
-          inches = F,ann=F,bg = "black",add=T)
-
-  if(indicate_bins) segments(shifted_centers$x[x$freq>=min_bin_freq],
-                             shifted_centers$y[x$freq>=min_bin_freq],
-                             ordered_centers$x[x$freq>=min_bin_freq],
-                             ordered_centers$y[x$freq>=min_bin_freq],
-                             col='red')
+  if(use_pvals){
+    symbols(shifted_centers[x$freq>=min_bin_freq,],
+            circles=sqrt(scale_area*rel_freq[x$freq>=min_bin_freq]/pi),
+            inches = F,ann=F,fg = test_col[x$freq>=min_bin_freq],bg = test_col[x$freq>=min_bin_freq],add=T)
+    if(indicate_bins) segments(shifted_centers$x[x$freq>=min_bin_freq],
+                               shifted_centers$y[x$freq>=min_bin_freq],
+                               ordered_centers$x[x$freq>=min_bin_freq],
+                               ordered_centers$y[x$freq>=min_bin_freq],
+                               col=test_col[x$freq>=min_bin_freq])
+  }
+  else{
+    symbols(shifted_centers[x$freq>=min_bin_freq,],
+            circles=sqrt(scale_area*rel_freq[x$freq>=min_bin_freq]/pi),
+            inches = F,ann=F,bg = "black",add=T)
+    if(indicate_bins) segments(shifted_centers$x[x$freq>=min_bin_freq],
+                               shifted_centers$y[x$freq>=min_bin_freq],
+                               ordered_centers$x[x$freq>=min_bin_freq],
+                               ordered_centers$y[x$freq>=min_bin_freq],
+                               col='red')
+  }
 
   centers_extremes = ordered_centers[c(1,n,n_bins),]
   c1 = 3/4
